function qh=errorbound(h)
% errorbound - error bound for midpoint quadrature rule
% 
%   Syntax: 
%           qh=errorbound(h)
%   Arguments: 
%           h - the stepsize, a positive real number
%   Returns: 
%           qh - the error bound (28.9) in chapter 28
%               
%   Description:
%           The program errorbound computes the error bound (28.9)
%           for the integral of 1/x from 1 to 4. 
%   Examples: 
%  
%   See also:
%          midpoint.m
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          
%   Author:
%          
%
%------------------------------+---------------------------------------+
Write your program here!

